==> nextcloud-29.0.5.tgz: nextcloud/apps/photos/l10n/it.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Collegamento pubblico",
    "Photos" : "Foto",
    "On This Day" : "In questo giorno",
    "Your memories under your control" : "I tuoi ricordi sotto il tuo controllo",
    "All media" : "Tutti i media",
    "Videos" : "Video",
    "Albums" : "Album",
    "Collaborative albums" : "Album collaborativi",
    "People" : "Persone",
    "Folders" : "Cartelle",
    "Favorites" : "Preferiti",
    "On this day" : "In questo giorno",
    "Shared with you" : "Condivise con te",
    "Tags" : "Etichette",
    "Places" : "Luoghi",
    "Map" : "Mappa",
    "Photos settings" : "Impostazioni foto",
    "Mark selection as favorite" : "Imposta selezione come preferiti",
    "Add selection to favorites" : "Aggiungi selezione ai preferiti",
    "Remove selection from favorites" : "Rimuovi selezione dai preferiti",
    "Name of the album" : "Nome dell'album",
    "Location of the album" : "Posizione dell'album",
    "Back" : "Indietro",
    "Add collaborators" : "Aggiungi collaboratori",
    "Save" : "Salva",
    "Create album" : "Crea l'album",
    "Add to Album" : "Aggiungi all'album",
    "Add selection to album {albumName}" : "Aggiungi selezione all'album {albumName}",
    "Shared by" : "Condiviso da",
    "Create a new album." : "Crea un nuovo album",
    "Create new album" : "Crea nuovo album",
    "New album" : "Nuovo album",
    "_%n item_::_%n photos and videos_" : ["%n oggetto ","%n foto e video","%n foto e video"],
    "Add people or groups who can edit your album" : "Aggiungi persone o gruppi che possono modificare il tuo album",
    "Search people or groups" : "Cerca persone o gruppi",
    "No recommendations. Start typing." : "Nessun consiglio. Inizia a scrivere.",
    "Group" : "Gruppo",
    "Remove {collaboratorLabel} from the collaborators list" : "Rimuovi {collaboratorLabel} dall'elenco dei collaboratori",
    "Copy the public link" : "Copia il collegamento pubblico",
    "Public link copied!" : "Collegamento pubblico copiato",
    "Copy public link" : "Copia collegamento pubblico",
    "Delete the public link" : "Elimina il collegamento pubblico",
    "Create public link share" : "Crea collegamento pubblico di condivisione",
    "Share via public link" : "Condividi tramite collegamento pubblico",
    "Failed to fetch collaborators list." : "Impossibile ottenere l'elenco dei collaboratori.",
    "Failed to update album." : "Aggiornamento album fallito.",
    "This collection does not exist" : "Questa collezione non esiste",
    "An error occurred" : "Si è verificato un errore",
    "No picture for this day" : "Non ci sono foto in questo giorno",
    "Picture taken on this day will show up here." : "Le foto di questo giorno appariranno qui.",
    "More photos from this day" : "Più foto di questo giorno",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto non assegnata","%n foto non assegnate","%n foto non assegnate"],
    "Favorite" : "Preferito",
    "Select image {imageName}" : "Seleziona immagine {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Immagine preferita, apri l'immagine \"{name}\" a dimensione intera",
    "Open the full size \"{name}\" image" : "Apri l'immagine \"{name}\" a dimensione piena",
    "Open the \"{name}\" folder" : "Apri la cartella \"{name}\"",
    "Go back" : "Indietro",
    "Back to {folder}" : "Torna a {folder}",
    "Share this folder" : "Condividi questa cartella",
    "Dates" : "Date",
    "Jump to specific date in list" : "Vai alla data specifica nella lista",
    "Jump to {date}" : "Vai a {date}",
    "Add to {destination}" : "Aggiungi a {destination}",
    "There are no photos or videos yet!" : "Non ci sono foto o video ancora",
    "_{years} year ago_::_{years} years ago_" : ["{years} anno fa","{years} anni fa","{years} anni fa"],
    "Enable squared photos view" : "Abilita vista foto quadrate",
    "Delete source directory" : "Rimuovi la cartella sorgente",
    "All folders" : "Tutte le cartelle",
    "Add a Photos source for the timelines" : "Aggiungi una sorgente Foto per le timelines",
    "Add folder" : "Aggiungi cartella",
    "Select a source folder for your media" : "Seleziona una cartella sorgente per i tuoi media",
    "Home" : "Home",
    "Choose default Photos upload and Albums location" : "Scegli il percorso predefinito di caricamento di foto e album",
    "Choose a different folder" : "Scegli una cartella diversa",
    "Select the default upload location for your media" : "Seleziona la locazione di upload di default per i tuoi media",
    "View" : "Visualizza",
    "Media folders" : "Cartelle dei media",
    "Choose the folders from where photos and videos are shown." : "Scegli le cartelle da dove foto e video vengono mostrati",
    "Upload folder" : "Cartella di upload",
    "Choose the folder where photos and albums are uploaded to." : "Scegli la cartella dove foto ed album verranno caricati",
    "_%n photo_::_%n photos_" : ["%n foto","%n foto","%n foto"],
    "Unselect all" : "Deseleziona tutto",
    "Manage collaborators for this album" : "Gestisci i collaboratori di questo album",
    "Open actions menu" : "Apri il menu azioni",
    "Edit album details" : "Modifica i dettagli dell'album",
    "Download all files in album" : "Scarica tutti i file nell'album",
    "Delete album" : "Elimina album",
    "Download selected files" : "Scarica i file selezionati",
    "Remove selection from album" : "Rimuovi selezione dall'album",
    "This album does not have any photos or videos yet!" : "Questo album non ha ne foto ne video al momento.",
    "Add photos to this album" : "Aggiungi foto a questo album",
    "Add photos to {albumName}" : "Aggiungi foto in {albumName}",
    "Manage collaborators" : "Gestisci collaboratori",
    "Save collaborators for this album." : "Salva i collaboratori per questo album.",
    "Cover photo for album {albumName}" : "Foto di cover per l'album {albumName}",
    "There is no album yet!" : "Non c'è nessun album ancora.",
    "This person could not be found" : "Impossibile trovare questa persona",
    "Rename person" : "Rinomina persona",
    "Merge with different person" : "Unisci ad un'altra persona",
    "Download selected photos" : "Scarica le foto selezionate",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Remove person" : "Rimuovi persona",
    "Name of this person" : "Nome della persona",
    "Save." : "Salva.",
    "Merge person" : "Unisci persona",
    "Move to different person" : "Sposta ad un'altra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Sposta foto ad un'altra persona","Sposta foto ad un'altra persona","Sposta foto ad un'altra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Rimuovi foto da persona","Rimuovi foto da persona","Rimuovi foto da persona"],
    "This might take some time depending on the size of your photo library." : "Potrebbe richiedere del tempo a seconda della dimensione della raccolta di foto.",
    "Recognized people will show up here" : "Le persone riconosciute appariranno qui",
    "This folder does not exist" : "Questa cartella non esiste",
    "Loading folders …" : "Caricamento cartelle …",
    "No photos in here" : "Nessuna foto qui",
    "Taken on {date} at {time}" : "Scattata il {date} alle {time}",
    "This place does not have any photos or videos yet!" : "Questo luogo non ha ancora foto o video!",
    "Add photos to this place" : "Aggiungi foto a questo luogo",
    "Cover photo for place {placeName}" : "Foto di copertina per il luogo {placeName}",
    "There is no place yet!" : "Non c'è ancora nessun luogo!",
    "Cover photo for shared album {albumName}." : "Foto di copertina per l'album condiviso {albumName}.",
    "Back to tags overview" : "Torna alla panoramica della etichette",
    "No photos with this tag yet" : "Ancora nessuna foto con questa etichetta",
    "No tags yet" : "Ancora nessun tag",
    "Photos with tags will show up here" : "Le foto con i tag saranno mostrate qui",
    "Popular tags" : "Etichette popolari",
    "One of the source folders does not exists" : "Una delle cartelle sorgenti non esiste",
    "Add" : "Aggiungi",
    "Add to album" : "Aggiungi all'album",
    "Delete selection" : "Elimina selezione",
    "No photos or videos in here" : "Nessuna foto o video qui",
    "Unassigned faces" : "Volti non assegnati",
    "_%n photos_::_%n photos_" : ["%n foto","%n foto","%n foto"],
    "Failed to fetch collection." : "Recupero della categoria non riuscito.",
    "Failed to fetch collections list." : "Recupero della lista di collezioni non riuscito.",
    "Failed to fetch faces list." : "Recupero della lista di volti non riuscito.",
    "All your media" : "Tutti i tuoi media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Album condivisi",
    "Shared album {title}" : "Album condiviso {title}",
    "Public album {title}" : "Album pubblico {title}",
    "Tagged photos" : "Foto con tag",
    "Tagged photo {title}" : "Foto etichettata {title}",
    "{title}'s face" : "Volto di {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Dettagli",
    "Failed to rename {oldName} to {faceName}." : "Rinominazione di {oldName} in {faceName} non riuscita.",
    "Failed to delete {faceName}." : "Eliminazione di {faceName} non riuscita.",
    "Failed to delete {fileId}." : "Eliminazione di {fileId} non riuscita.",
    "Failed to delete {fileName}." : "Eliminazione di {fileName} non riuscita.",
    "Failed to set favorite state for {fileId}." : "Impostazione dello stato di preferito a {fileId} non riuscita.",
    "Failed to set favorite state for {fileName}." : "Impostazione dello stato di preferito a {fileName} non riuscita.",
    "Could not load photos folder" : "Non è stato possibile caricare la cartella foto",
    "Default Photos upload and Albums location" : "Percorso predefinito caricamento foto e album",
    "Select the default location for your media" : "Seleziona il percorso predefinito per i tuoi file",
    "Invalid location selected" : "Percorso selezionato non valido",
    "Photos directory" : "Cartella delle foto"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/photos/l10n/it.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Collegamento pubblico",
    "Photos" : "Foto",
    "On This Day" : "In questo giorno",
    "Your memories under your control" : "I tuoi ricordi sotto il tuo controllo",
    "All media" : "Tutti i media",
    "Videos" : "Video",
    "Albums" : "Album",
    "Collaborative albums" : "Album collaborativi",
    "People" : "Persone",
    "Folders" : "Cartelle",
    "Favorites" : "Preferiti",
    "On this day" : "In questo giorno",
    "Shared with you" : "Condivise con te",
    "Tags" : "Etichette",
    "Places" : "Luoghi",
    "Map" : "Mappa",
    "Photos settings" : "Impostazioni foto",
    "Mark selection as favorite" : "Imposta selezione come preferiti",
    "Add selection to favorites" : "Aggiungi selezione ai preferiti",
    "Remove selection from favorites" : "Rimuovi selezione dai preferiti",
    "Name of the album" : "Nome dell'album",
    "Location of the album" : "Posizione dell'album",
    "Back" : "Indietro",
    "Add collaborators" : "Aggiungi collaboratori",
    "Save" : "Salva",
    "Create album" : "Crea l'album",
    "Add to Album" : "Aggiungi all'album",
    "Add selection to album {albumName}" : "Aggiungi selezione all'album {albumName}",
    "Shared by" : "Condiviso da",
    "Create a new album." : "Crea un nuovo album",
    "Create new album" : "Crea nuovo album",
    "New album" : "Nuovo album",
    "_%n item_::_%n photos and videos_" : ["%n oggetto ","%n foto e video","%n foto e video"],
    "Add people or groups who can edit your album" : "Aggiungi persone o gruppi che possono modificare il tuo album",
    "Search people or groups" : "Cerca persone o gruppi",
    "No recommendations. Start typing." : "Nessun consiglio. Inizia a scrivere.",
    "Group" : "Gruppo",
    "Remove {collaboratorLabel} from the collaborators list" : "Rimuovi {collaboratorLabel} dall'elenco dei collaboratori",
    "Copy the public link" : "Copia il collegamento pubblico",
    "Public link copied!" : "Collegamento pubblico copiato",
    "Copy public link" : "Copia collegamento pubblico",
    "Delete the public link" : "Elimina il collegamento pubblico",
    "Create public link share" : "Crea collegamento pubblico di condivisione",
    "Share via public link" : "Condividi tramite collegamento pubblico",
    "Failed to fetch collaborators list." : "Impossibile ottenere l'elenco dei collaboratori.",
    "Failed to update album." : "Aggiornamento album fallito.",
    "This collection does not exist" : "Questa collezione non esiste",
    "An error occurred" : "Si è verificato un errore",
    "No picture for this day" : "Non ci sono foto in questo giorno",
    "Picture taken on this day will show up here." : "Le foto di questo giorno appariranno qui.",
    "More photos from this day" : "Più foto di questo giorno",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n foto non assegnata","%n foto non assegnate","%n foto non assegnate"],
    "Favorite" : "Preferito",
    "Select image {imageName}" : "Seleziona immagine {imageName}",
    "Favorite image, open the full size \"{name}\" image" : "Immagine preferita, apri l'immagine \"{name}\" a dimensione intera",
    "Open the full size \"{name}\" image" : "Apri l'immagine \"{name}\" a dimensione piena",
    "Open the \"{name}\" folder" : "Apri la cartella \"{name}\"",
    "Go back" : "Indietro",
    "Back to {folder}" : "Torna a {folder}",
    "Share this folder" : "Condividi questa cartella",
    "Dates" : "Date",
    "Jump to specific date in list" : "Vai alla data specifica nella lista",
    "Jump to {date}" : "Vai a {date}",
    "Add to {destination}" : "Aggiungi a {destination}",
    "The destination folder is owned by {owner}" : "La cartella di destinazione è di proprietà di {owner}",
    "There are no photos or videos yet!" : "Non ci sono foto o video ancora",
    "_{years} year ago_::_{years} years ago_" : ["{years} anno fa","{years} anni fa","{years} anni fa"],
    "Enable squared photos view" : "Abilita vista foto quadrate",
    "Delete source directory" : "Rimuovi la cartella sorgente",
    "All folders" : "Tutte le cartelle",
    "Add a Photos source for the timelines" : "Aggiungi una sorgente Foto per le timelines",
    "Add folder" : "Aggiungi cartella",
    "Pick folder" : "Scegli cartella",
    "Select a source folder for your media" : "Seleziona una cartella sorgente per i tuoi media",
    "Home" : "Home",
    "Choose default Photos upload and Albums location" : "Scegli il percorso predefinito di caricamento di foto e album",
    "Choose a different folder" : "Scegli una cartella diversa",
    "Select the default upload location for your media" : "Seleziona la locazione di upload di default per i tuoi media",
    "View" : "Visualizza",
    "Media folders" : "Cartelle dei media",
    "Choose the folders from where photos and videos are shown." : "Scegli le cartelle da dove foto e video vengono mostrati",
    "Upload folder" : "Cartella di upload",
    "Choose the folder where photos and albums are uploaded to." : "Scegli la cartella dove foto ed album verranno caricati",
    "_%n photo_::_%n photos_" : ["%n foto","%n foto","%n foto"],
    "Unselect all" : "Deseleziona tutto",
    "Add photos to this album" : "Aggiungi foto a questo album",
    "Manage collaborators for this album" : "Gestisci i collaboratori di questo album",
    "Open actions menu" : "Apri il menu azioni",
    "Edit album details" : "Modifica i dettagli dell'album",
    "Download all files in album" : "Scarica tutti i file nell'album",
    "Delete album" : "Elimina album",
    "Download selected files" : "Scarica i file selezionati",
    "Remove selection from album" : "Rimuovi selezione dall'album",
    "This album does not have any photos or videos yet!" : "Questo album non ha ne foto ne video al momento.",
    "Add photos to {albumName}" : "Aggiungi foto in {albumName}",
    "Manage collaborators" : "Gestisci collaboratori",
    "Save collaborators for this album." : "Salva i collaboratori per questo album.",
    "Cover photo for album {albumName}" : "Foto di cover per l'album {albumName}",
    "There is no album yet!" : "Non c'è nessun album ancora.",
    "This person could not be found" : "Impossibile trovare questa persona",
    "Rename person" : "Rinomina persona",
    "Merge with different person" : "Unisci ad un'altra persona",
    "Download selected photos" : "Scarica le foto selezionate",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Remove person" : "Rimuovi persona",
    "Name of this person" : "Nome della persona",
    "Save." : "Salva.",
    "Merge person" : "Unisci persona",
    "Move to different person" : "Sposta ad un'altra persona",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Sposta foto ad un'altra persona","Sposta foto ad un'altra persona","Sposta foto ad un'altra persona"],
    "_Remove photo from person_::_Remove photos from person_" : ["Rimuovi foto da persona","Rimuovi foto da persona","Rimuovi foto da persona"],
    "This might take some time depending on the size of your photo library." : "Potrebbe richiedere del tempo a seconda della dimensione della raccolta di foto.",
    "Recognized people will show up here" : "Le persone riconosciute appariranno qui",
    "This folder does not exist" : "Questa cartella non esiste",
    "Loading folders …" : "Caricamento cartelle …",
    "No photos in here" : "Nessuna foto qui",
    "Taken on {date} at {time}" : "Scattata il {date} alle {time}",
    "This place does not have any photos or videos yet!" : "Questo luogo non ha ancora foto o video!",
    "Add photos to this place" : "Aggiungi foto a questo luogo",
    "Cover photo for place {placeName}" : "Foto di copertina per il luogo {placeName}",
    "There is no place yet!" : "Non c'è ancora nessun luogo!",
    "Cover photo for shared album {albumName}." : "Foto di copertina per l'album condiviso {albumName}.",
    "Back to tags overview" : "Torna alla panoramica della etichette",
    "No photos with this tag yet" : "Ancora nessuna foto con questa etichetta",
    "No tags yet" : "Ancora nessun tag",
    "Photos with tags will show up here" : "Le foto con i tag saranno mostrate qui",
    "Popular tags" : "Etichette popolari",
    "All tags" : "Tutte le etichette",
    "One of the source folders does not exist" : "Una delle cartelle di origine non esiste",
    "Add to album" : "Aggiungi all'album",
    "Delete selection" : "Elimina selezione",
    "No photos or videos in here" : "Nessuna foto o video qui",
    "Unassigned faces" : "Volti non assegnati",
    "_%n photos_::_%n photos_" : ["%n foto","%n foto","%n foto"],
    "Failed to fetch collection." : "Recupero della categoria non riuscito.",
    "Failed to fetch collections list." : "Recupero della lista di collezioni non riuscito.",
    "Failed to fetch faces list." : "Recupero della lista di volti non riuscito.",
    "All your media" : "Tutti i tuoi media",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Album condivisi",
    "Shared album {title}" : "Album condiviso {title}",
    "Public album {title}" : "Album pubblico {title}",
    "Tagged photos" : "Foto con tag",
    "Tagged photo {title}" : "Foto etichettata {title}",
    "{title}'s face" : "Volto di {title}",
    "{startDate} to {endDate}" : "{startDate} a {endDate}",
    "Details" : "Dettagli",
    "Failed to rename {oldName} to {faceName}." : "Rinominazione di {oldName} in {faceName} non riuscita.",
    "Failed to delete {faceName}." : "Eliminazione di {faceName} non riuscita.",
    "Failed to delete {fileId}." : "Eliminazione di {fileId} non riuscita.",
    "Failed to delete {fileName}." : "Eliminazione di {fileName} non riuscita.",
    "Failed to set favorite state for {fileId}." : "Impostazione dello stato di preferito a {fileId} non riuscita.",
    "Failed to set favorite state for {fileName}." : "Impostazione dello stato di preferito a {fileName} non riuscita.",
    "Could not load photos folder" : "Non è stato possibile caricare la cartella foto",
    "One of the source folders does not exists" : "Una delle cartelle sorgenti non esiste",
    "Add" : "Aggiungi"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
